@@ -13,19 +13,16 @@ API for halo_finding
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-from halo_objects import \
+from .halo_objects import \
     Halo, \
     HOPHalo, \
-    parallelHOPHalo, \
     LoadedHalo, \
     FOFHalo, \
     HaloList, \
     HOPHaloList, \
     FOFHaloList, \
-    parallelHOPHaloList, \
     LoadedHaloList, \
     GenericHaloFinder, \
-    parallelHF, \
     HOPHaloFinder, \
     FOFHaloFinder, \
     HaloFinder, \
