@@ -7,7 +7,11 @@ from yt.utilities.definitions import \
 from yt.frontends.stream.fields import \
     StreamFieldInfo
 from yt.units.yt_array import \
-     YTArray, YTQuantity
+    array_like_field, \
+    YTArray, YTQuantity
+from yt.utilities.exceptions import \
+    YTFieldUnitError, \
+    YTFieldUnitParseError
 
 def setup():
     global base_ds
@@ -123,8 +127,8 @@ class TestFieldAccess(object):
         fields = list(_base_fields)
 
         for rf in requested:
-            if field.particle_type:
-                if rf not in particle_fields:
+            if rf[0] == 'io' or rf[0] == 'all':
+                if rf not in particle_fields or rf[1] not in particle_fields:
                     particle_fields.append(rf[1])
             else:
                 fields.append(rf)
@@ -257,9 +261,17 @@ def test_add_field_unit_semantics():
     assert_equal(str(ad['dimensionless_explicit'].units), 'dimensionless')
     assert_raises(YTFieldUnitError, get_data, ds, 'dimensionful')
 
+def test_array_like_field():
+    ds = fake_random_ds(4, particles=64)
+    ad = ds.all_data()
+    u1 = ad["particle_mass"].units
+    u2 = array_like_field(ad, 1., ("all", "particle_mass")).units
+    assert u1 == u2
+
 if __name__ == "__main__":
     setup()
     for t in test_all_fields():
         t()
     test_add_deposited_particle_field()
     test_add_field_unit_semantics()
+    test_array_like_field()
