@@ -193,7 +193,7 @@ class ARTDataset(Dataset):
         particle header, star files, etc.
         """
         base_prefix, base_suffix = filename_pattern['amr']
-        aexpstr = 'a'+file_amr.rsplit('a',1)[1].replace(base_suffix,'')
+        numericstr = file_amr.rsplit('_',1)[1].replace(base_suffix,'')
         possibles = glob.glob(os.path.dirname(os.path.abspath(file_amr))+"/*")
         for filetype, (prefix, suffix) in filename_pattern.items():
             # if this attribute is already set skip it
@@ -201,7 +201,10 @@ class ARTDataset(Dataset):
                 continue
             match = None
             for possible in possibles:
-                if possible.endswith(aexpstr+suffix):
+                if possible.endswith(numericstr+suffix):
+                    if os.path.basename(possible).startswith(prefix):
+                        match = possible
+                elif possible.endswith(suffix):
                     if os.path.basename(possible).startswith(prefix):
                         match = possible
             if match is not None:
@@ -292,6 +295,11 @@ class ARTDataset(Dataset):
                                      self.root_ncells)
             self.iOctFree, self.nOct = fpu.read_vector(f, 'i', '>')
             self.child_grid_offset = f.tell()
+            # lextra needs to be loaded as a string, but it's actually
+            # array values.  So pop it off here, and then re-insert.
+            lextra = amr_header_vals.pop("lextra")
+            amr_header_vals['lextra'] = np.fromstring(
+                lextra, '>f4')
             self.parameters.update(amr_header_vals)
             amr_header_vals = None
             # estimate the root level
@@ -313,6 +321,11 @@ class ARTDataset(Dataset):
                 n = particle_header_vals['Nspecies']
                 wspecies = np.fromfile(fh, dtype='>f', count=10)
                 lspecies = np.fromfile(fh, dtype='>i', count=10)
+                # extras needs to be loaded as a string, but it's actually
+                # array values.  So pop it off here, and then re-insert.
+                extras = particle_header_vals.pop("extras")
+                particle_header_vals['extras'] = np.fromstring(
+                    extras, '>f4')
             self.parameters['wspecies'] = wspecies[:n]
             self.parameters['lspecies'] = lspecies[:n]
             for specie in range(n):
@@ -435,7 +448,7 @@ class DarkMatterARTDataset(ARTDataset):
         base_prefix, base_suffix = filename_pattern['particle_data']
         aexpstr = file_particle.rsplit('s0',1)[1].replace(base_suffix,'')
         possibles = glob.glob(os.path.dirname(os.path.abspath(file_particle))+"/*")
-        for filetype, (prefix, suffix) in filename_pattern.iteritems():
+        for filetype, (prefix, suffix) in filename_pattern.items():
             # if this attribute is already set skip it
             if getattr(self, "_file_"+filetype, None) is not None:
                 continue
