@@ -23,12 +23,12 @@ from yt.fields.field_detector import \
     FieldDetector
 from yt.units.yt_array import \
     YTArray
-
 from yt.utilities.physical_constants import \
     mh, \
     mass_sun_cgs, \
     boltzmann_constant_cgs, \
     amu_cgs
+import numpy as np
 
 b_units = "code_magnetic"
 ra_units = "code_length / code_time**2"
@@ -104,14 +104,27 @@ class ARTIOFieldInfo(FieldInfoContainer):
         self.add_field(("gas", "temperature"), function = _temperature,
                        units = "K")
 
-        def _metal_density(field, data):
-            tr = data["metal_ia_density"]
-            tr += data["metal_ii_density"]
-            return tr
-        self.add_field(("gas","metal_density"),
-                       function=_metal_density,
-                       units="g/cm**3",
-                       take_log=True)
+        # Create a metal_density field as sum of existing metal fields. 
+        flag1 = ("artio", "HVAR_METAL_DENSITY_Ia") in self.field_list
+        flag2 = ("artio", "HVAR_METAL_DENSITY_II") in self.field_list
+        if flag1 or flag2:
+            if flag1 and flag2:
+                def _metal_density(field, data):
+                    tr = data['metal_ia_density'].copy()
+                    np.add(tr, data["metal_ii_density"], out=tr)
+                    return tr
+            elif flag1 and not flag2:
+                def _metal_density(field, data):
+                    tr = data["metal_ia_density"]
+                    return tr
+            else:
+                def _metal_density(field, data):
+                    tr = data["metal_ii_density"]
+                    return tr
+            self.add_field(("gas","metal_density"),
+                           function=_metal_density,
+                           units="g/cm**3",
+                           take_log=True)
 
     def setup_particle_fields(self, ptype):
         if ptype == "STAR":
