@@ -23,6 +23,8 @@ from yt.frontends.athena.api import AthenaDataset
 from yt.config import ytcfg
 from yt.convenience import load
 
+import yt.units as u
+
 _fields_cloud = ("scalar[0]", "density", "total_energy")
 
 cloud = "ShockCloud/id0/Cloud.0050.vtk"
@@ -62,9 +64,9 @@ def test_stripping():
 
 sloshing = "MHDSloshing/virgo_low_res.0054.vtk"
 
-uo_sloshing = {"length_unit":(1.0,"Mpc"),
-               "time_unit":(1.0,"Myr"),
-               "mass_unit":(1.0e14,"Msun")}
+uo_sloshing = {"length_unit": (1.0,"Mpc"),
+               "time_unit": (1.0,"Myr"),
+               "mass_unit": (1.0e14,"Msun")}
 
 @requires_file(sloshing)
 def test_nprocs():
@@ -77,6 +79,11 @@ def test_nprocs():
     sp2 = ds2.sphere("c", (100.,"kpc"))
     prj2 = ds1.proj("density",0)
 
+    ds3 = load(sloshing, parameters=uo_sloshing)
+    assert_equal(ds3.length_unit, u.Mpc)
+    assert_equal(ds3.time_unit, u.Myr)
+    assert_equal(ds3.mass_unit, 1e14*u.Msun)
+
     yield assert_equal, sp1.quantities.extrema("pressure"), sp2.quantities.extrema("pressure")
     yield assert_allclose_units, sp1.quantities.total_quantity("pressure"), sp2.quantities.total_quantity("pressure")
     for ax in "xyz":
