@@ -15,7 +15,8 @@ Chombo frontend tests
 
 from yt.testing import \
     requires_file, \
-    assert_equal
+    assert_equal, \
+    units_override_check
 from yt.utilities.answer_testing.framework import \
     requires_ds, \
     small_patch_amr, \
@@ -46,8 +47,16 @@ def test_tb():
         test_tb.__name__ = test.description
         yield test
 
-_zp_fields = ("rhs", "phi", "gravitational_field_x",
-              "gravitational_field_y")
+iso = "IsothermalSphere/data.0000.3d.hdf5"
+@requires_ds(iso)
+def test_iso():
+    ds = data_dir_load(iso)
+    yield assert_equal, str(ds), "data.0000.3d.hdf5"
+    for test in small_patch_amr(iso, _fields):
+        test_iso.__name__ = test.description
+        yield test
+
+_zp_fields = ("rhs", "phi")
 zp = "ZeldovichPancake/plt32.2d.hdf5"
 @requires_ds(zp)
 def test_zp():
@@ -55,7 +64,7 @@ def test_zp():
     yield assert_equal, str(ds), "plt32.2d.hdf5"
     for test in small_patch_amr(zp, _zp_fields, input_center="c",
                                 input_weight="rhs"):
-        test_tb.__name__ = test.description
+        test_zp.__name__ = test.description
         yield test
 
 kho = "KelvinHelmholtz/data.0004.hdf5"
@@ -64,7 +73,7 @@ def test_kho():
     ds = data_dir_load(kho)
     yield assert_equal, str(ds), "data.0004.hdf5"
     for test in small_patch_amr(kho, _fields):
-        test_gc.__name__ = test.description
+        test_kho.__name__ = test.description
         yield test
 
 @requires_file(zp)
@@ -80,3 +89,18 @@ def test_Orion2Dataset():
 @requires_file(kho)
 def test_PlutoDataset():
     assert isinstance(data_dir_load(kho), PlutoDataset)
+
+@requires_file(zp)
+def test_units_override_zp():
+    for test in units_override_check(zp):
+        yield test
+
+@requires_file(gc)
+def test_units_override_gc():
+    for test in units_override_check(gc):
+        yield test
+
+@requires_file(kho)
+def test_units_override_kho():
+    for test in units_override_check(kho):
+        yield test
