@@ -21,6 +21,7 @@ from yt.utilities.io_handler import \
     BaseIOHandler, _axis_ids
 from yt.utilities.logger import ytLogger as mylog
 from yt.geometry.selection_routines import mask_fill, AlwaysSelector
+from yt.extern.six import u, b, iteritems
 import h5py
 
 import numpy as np
@@ -34,6 +35,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
 
     _dataset_type = "enzo_packed_3d"
     _base = slice(None)
+    _field_dtype = "float64"
 
     def _read_field_names(self, grid):
         if grid.filename is None: return []
@@ -43,9 +45,12 @@ class IOHandlerPackedHDF5(BaseIOHandler):
         except KeyError:
             group = f
         fields = []
+        dtypes = set([])
         add_io = "io" in grid.ds.particle_types
-        for name, v in group.iteritems():
+        for name, v in iteritems(group):
             # NOTE: This won't work with 1D datasets or references.
+            # For all versions of Enzo I know about, we can assume all floats
+            # are of the same size.  So, let's grab one.
             if not hasattr(v, "shape") or v.dtype == "O":
                 continue
             elif len(v.dims) == 1:
@@ -55,6 +60,16 @@ class IOHandlerPackedHDF5(BaseIOHandler):
                     fields.append( ("io", str(name)) )
             else:
                 fields.append( ("enzo", str(name)) )
+                dtypes.add(v.dtype)
+
+        if len(dtypes) == 1:
+            # Now, if everything we saw was the same dtype, we can go ahead and
+            # set it here.  We do this because it is a HUGE savings for 32 bit
+            # floats, since our numpy copying/casting is way faster than
+            # h5py's, for some reason I don't understand.  This does *not* need
+            # to be correct -- it will get fixed later -- it just needs to be
+            # okay for now.
+            self._field_dtype = list(dtypes)[0]
         f.close()
         return fields
 
@@ -70,7 +85,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
                 if g.filename is None: continue
                 if f is None:
                     #print "Opening (count) %s" % g.filename
-                    f = h5py.File(g.filename.encode('ascii'), "r")
+                    f = h5py.File(g.filename, "r")
                 nap = sum(g.NumberOfActiveParticles.values())
                 if g.NumberOfParticles == 0 and nap == 0:
                     continue
@@ -99,7 +114,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
                 if g.filename is None: continue
                 if f is None:
                     #print "Opening (read) %s" % g.filename
-                    f = h5py.File(g.filename.encode('ascii'), "r")
+                    f = h5py.File(g.filename, "r")
                 nap = sum(g.NumberOfActiveParticles.values())
                 if g.NumberOfParticles == 0 and nap == 0:
                     continue
@@ -131,7 +146,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
             if not (len(chunks) == len(chunks[0].objs) == 1):
                 raise RuntimeError
             g = chunks[0].objs[0]
-            f = h5py.File(g.filename.encode('ascii'), 'r')
+            f = h5py.File(u(g.filename), 'r')
             if g.id in self._cached_fields:
                 gf = self._cached_fields[g.id]
                 rv.update(gf)
@@ -164,14 +179,15 @@ class IOHandlerPackedHDF5(BaseIOHandler):
         mylog.debug("Reading %s cells of %s fields in %s grids",
                    size, [f2 for f1, f2 in fields], ng)
         ind = 0
+        h5_type = self._field_dtype
         for chunk in chunks:
             fid = None
             for g in chunk.objs:
                 if g.filename is None: continue
                 if fid is None:
-                    fid = h5py.h5f.open(g.filename.encode('ascii'), h5py.h5f.ACC_RDONLY)
+                    fid = h5py.h5f.open(b(g.filename), h5py.h5f.ACC_RDONLY)
                 gf = self._cached_fields.get(g.id, {})
-                data = np.empty(g.ActiveDimensions[::-1], dtype="float64")
+                data = np.empty(g.ActiveDimensions[::-1], dtype=h5_type)
                 data_view = data.swapaxes(0,2)
                 nd = 0
                 for field in fields:
@@ -183,7 +199,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
                     ftype, fname = field
                     try:
                         node = "/Grid%08i/%s" % (g.id, fname)
-                        dg = h5py.h5d.open(fid, node.encode('ascii'))
+                        dg = h5py.h5d.open(fid, b(node))
                     except KeyError:
                         if fname == "Dark_Matter_Density": continue
                         raise
@@ -250,6 +266,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
             rv.update(self._read_particle_selection(
               [chunk], selector, particle_fields))
         if len(fluid_fields) == 0: return rv
+        h5_type = self._field_dtype
         for g in chunk.objs:
             rv[g.id] = gf = {}
             if g.id in self._cached_fields:
@@ -259,9 +276,9 @@ class IOHandlerPackedHDF5(BaseIOHandler):
                 if fid is not None: fid.close()
                 fid = None
             if fid is None:
-                fid = h5py.h5f.open(g.filename.encode('ascii'), h5py.h5f.ACC_RDONLY)
+                fid = h5py.h5f.open(b(g.filename), h5py.h5f.ACC_RDONLY)
                 fn = g.filename
-            data = np.empty(g.ActiveDimensions[::-1], dtype="float64")
+            data = np.empty(g.ActiveDimensions[::-1], dtype=h5_type)
             data_view = data.swapaxes(0,2)
             for field in fluid_fields:
                 if field in gf:
@@ -271,7 +288,7 @@ class IOHandlerPackedHDF5(BaseIOHandler):
                 ftype, fname = field
                 try:
                     node = "/Grid%08i/%s" % (g.id, fname)
-                    dg = h5py.h5d.open(fid, node.encode('ascii'))
+                    dg = h5py.h5d.open(fid, b(node))
                 except KeyError:
                     if fname == "Dark_Matter_Density": continue
                     raise
