@@ -13,36 +13,34 @@ EnzoSimulation class and member functions.
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-from yt.funcs import *
-
 import numpy as np
 import glob
 import os
 
 from yt.convenience import \
-    load
+    load, \
+    only_on_root
 from yt.data_objects.time_series import \
     SimulationTimeSeries, DatasetSeries
 from yt.units import dimensions
 from yt.units.unit_registry import \
-     UnitRegistry
+    UnitRegistry
 from yt.units.yt_array import \
-     YTArray, YTQuantity
+    YTArray, YTQuantity
 from yt.utilities.cosmology import \
     Cosmology
-from yt.utilities.definitions import \
-    sec_conversion
 from yt.utilities.exceptions import \
     InvalidSimulationTimeSeries, \
     MissingParameter, \
     NoStoppingCondition
+from yt.utilities.logger import ytLogger as \
+    mylog
 from yt.utilities.parallel_tools.parallel_analysis_interface import \
     parallel_objects
-from yt.utilities.physical_constants import \
-    gravitational_constant_cgs as G
-
+    
 class EnzoSimulation(SimulationTimeSeries):
-    r"""Initialize an Enzo Simulation object.
+    r"""
+    Initialize an Enzo Simulation object.
 
     Upon creation, the parameter file is parsed and the time and redshift
     are calculated and stored in all_outputs.  A time units dictionary is
@@ -63,14 +61,8 @@ class EnzoSimulation(SimulationTimeSeries):
 
     Examples
     --------
-    >>> from yt.mods import *
-    >>> es = EnzoSimulation("my_simulation.par")
-    >>> es.get_time_series()
-    >>> for ds in es:
-    ...     print ds.current_time
-
-    >>> from yt.mods import *
-    >>> es = simulation("my_simulation.par", "Enzo")
+    >>> import yt
+    >>> es = yt.simulation("my_simulation.par", "Enzo")
     >>> es.get_time_series()
     >>> for ds in es:
     ...     print ds.current_time
@@ -78,7 +70,8 @@ class EnzoSimulation(SimulationTimeSeries):
     """
 
     def __init__(self, parameter_filename, find_outputs=False):
-
+        self.simulation_type = "grid"
+        self.key_parameters = ["stop_cycle"]
         SimulationTimeSeries.__init__(self, parameter_filename,
                                       find_outputs=find_outputs)
 
@@ -87,14 +80,14 @@ class EnzoSimulation(SimulationTimeSeries):
         self.unit_registry.lut["code_time"] = (1.0, dimensions.time)
         if self.cosmological_simulation:
             # Instantiate EnzoCosmology object for units and time conversions.
-            self.enzo_cosmology = \
+            self.cosmology = \
               EnzoCosmology(self.parameters['CosmologyHubbleConstantNow'],
                             self.parameters['CosmologyOmegaMatterNow'],
                             self.parameters['CosmologyOmegaLambdaNow'],
                             0.0, self.parameters['CosmologyInitialRedshift'],
                             unit_registry=self.unit_registry)
 
-            self.time_unit = self.enzo_cosmology.time_unit.in_units("s")
+            self.time_unit = self.cosmology.time_unit.in_units("s")
             self.unit_registry.modify("h", self.hubble_constant)
             # Comoving lengths
             for my_unit in ["m", "pc", "AU", "au"]:
@@ -160,7 +153,7 @@ class EnzoSimulation(SimulationTimeSeries):
             used in combination with either final_time or
             final_redshift.
             Default: None.
-        final_time : float
+        final_redshift : float
             The latest redshift for outputs to be included.  If None,
             the final redshift of the simulation is used.  This can be
             used in combination with either initial_time or
@@ -197,8 +190,8 @@ class EnzoSimulation(SimulationTimeSeries):
         Examples
         --------
 
-        >>> from yt.mods import *
-        >>> es = simulation("my_simulation.par", "Enzo")
+        >>> import yt
+        >>> es = yt.simulation("my_simulation.par", "Enzo")
         
         >>> es.get_time_series(initial_redshift=10, final_time=(13.7, "Gyr"), 
                                redshift_data=False)
@@ -207,8 +200,6 @@ class EnzoSimulation(SimulationTimeSeries):
 
         >>> es.get_time_series(final_cycle=100000)
 
-        >>> es.get_time_series(find_outputs=True)
-
         >>> # after calling get_time_series
         >>> for ds in es.piter():
         ...     p = ProjectionPlot(ds, 'x', "density")
@@ -226,7 +217,9 @@ class EnzoSimulation(SimulationTimeSeries):
         if (initial_redshift is not None or \
             final_redshift is not None) and \
             not self.cosmological_simulation:
-            raise InvalidSimulationTimeSeries('An initial or final redshift has been given for a noncosmological simulation.')
+            raise InvalidSimulationTimeSeries(
+                "An initial or final redshift has been given for a " +
+                "noncosmological simulation.")
 
         if time_data and redshift_data:
             my_all_outputs = self.all_outputs
@@ -244,12 +237,14 @@ class EnzoSimulation(SimulationTimeSeries):
 
         # Apply selection criteria to the set.
         if times is not None:
-            my_outputs = self._get_outputs_by_time(times, tolerance=tolerance,
-                                                   outputs=my_all_outputs)
+            my_outputs = self._get_outputs_by_key("time", times,
+                                                  tolerance=tolerance,
+                                                  outputs=my_all_outputs)
 
         elif redshifts is not None:
-            my_outputs = self._get_outputs_by_redshift(redshifts, tolerance=tolerance,
-                                                       outputs=my_all_outputs)
+            my_outputs = self._get_outputs_by_key("redshift", redshifts,
+                                                  tolerance=tolerance,
+                                                  outputs=my_all_outputs)
 
         elif initial_cycle is not None or final_cycle is not None:
             if initial_cycle is None:
@@ -272,9 +267,11 @@ class EnzoSimulation(SimulationTimeSeries):
                 elif isinstance(initial_time, tuple) and len(initial_time) == 2:
                     initial_time = self.quan(*initial_time)
                 elif not isinstance(initial_time, YTArray):
-                    raise RuntimeError("Error: initial_time must be given as a float or tuple of (value, units).")
+                    raise RuntimeError(
+                        "Error: initial_time must be given as a float or " +
+                        "tuple of (value, units).")
             elif initial_redshift is not None:
-                my_initial_time = self.enzo_cosmology.t_from_z(initial_redshift)
+                my_initial_time = self.cosmology.t_from_z(initial_redshift)
             else:
                 my_initial_time = self.initial_time
 
@@ -284,10 +281,12 @@ class EnzoSimulation(SimulationTimeSeries):
                 elif isinstance(final_time, tuple) and len(final_time) == 2:
                     final_time = self.quan(*final_time)
                 elif not isinstance(final_time, YTArray):
-                    raise RuntimeError("Error: final_time must be given as a float or tuple of (value, units).")
+                    raise RuntimeError(
+                        "Error: final_time must be given as a float or " +
+                        "tuple of (value, units).")
                 my_final_time = final_time.in_units("s")
             elif final_redshift is not None:
-                my_final_time = self.enzo_cosmology.t_from_z(final_redshift)
+                my_final_time = self.cosmology.t_from_z(final_redshift)
             else:
                 my_final_time = self.final_time
 
@@ -390,8 +389,9 @@ class EnzoSimulation(SimulationTimeSeries):
                     raise MissingParameter(self.parameter_filename, v)
                 setattr(self, a, self.parameters[v])
         else:
+            self.cosmological_simulation = 0
             self.omega_lambda = self.omega_matter = \
-                self.hubble_constant = self.cosmological_simulation = 0.0
+                self.hubble_constant = 0.0
 
         # make list of redshift outputs
         self.all_redshift_outputs = []
@@ -405,16 +405,10 @@ class EnzoSimulation(SimulationTimeSeries):
             del output['index']
         self.all_redshift_outputs = redshift_outputs
 
-    def _calculate_redshift_dump_times(self):
-        "Calculates time from redshift of redshift outputs."
-
-        if not self.cosmological_simulation: return
-        for output in self.all_redshift_outputs:
-            output['time'] = self.enzo_cosmology.t_from_z(output['redshift'])
-        self.all_redshift_outputs.sort(key=lambda obj:obj['time'])
-
     def _calculate_time_outputs(self):
-        "Calculate time outputs and their redshifts if cosmological."
+        """
+        Calculate time outputs and their redshifts if cosmological.
+        """
 
         self.all_time_outputs = []
         if self.final_time is None or \
@@ -432,7 +426,7 @@ class EnzoSimulation(SimulationTimeSeries):
             output = {'index': index, 'filename': filename, 'time': current_time.copy()}
             output['time'] = min(output['time'], self.final_time)
             if self.cosmological_simulation:
-                output['redshift'] = self.enzo_cosmology.z_from_t(current_time)
+                output['redshift'] = self.cosmology.z_from_t(current_time)
 
             self.all_time_outputs.append(output)
             if np.abs(self.final_time - current_time) / self.final_time < 1e-4: break
@@ -440,7 +434,9 @@ class EnzoSimulation(SimulationTimeSeries):
             index += 1
 
     def _calculate_cycle_outputs(self):
-        "Calculate cycle outputs."
+        """
+        Calculate cycle outputs.
+        """
 
         mylog.warn('Calculating cycle outputs.  Dataset times will be unavailable.')
 
@@ -460,7 +456,9 @@ class EnzoSimulation(SimulationTimeSeries):
             index += 1
 
     def _get_all_outputs(self, find_outputs=False):
-        "Get all potential datasets and combine into a time-sorted list."
+        """
+        Get all potential datasets and combine into a time-sorted list.
+        """
 
         # Create the set of outputs from which further selection will be done.
         if find_outputs:
@@ -468,8 +466,12 @@ class EnzoSimulation(SimulationTimeSeries):
 
         elif self.parameters['dtDataDump'] > 0 and \
           self.parameters['CycleSkipDataDump'] > 0:
-            mylog.info("Simulation %s has both dtDataDump and CycleSkipDataDump set.", self.parameter_filename )
-            mylog.info("    Unable to calculate datasets.  Attempting to search in the current directory")
+            mylog.info(
+                "Simulation %s has both dtDataDump and CycleSkipDataDump set.",
+                self.parameter_filename )
+            mylog.info(
+                "    Unable to calculate datasets.  " +
+                "Attempting to search in the current directory")
             self._find_outputs()
 
         else:
@@ -480,7 +482,10 @@ class EnzoSimulation(SimulationTimeSeries):
                 self._calculate_time_outputs()
 
             # Calculate times for redshift outputs.
-            self._calculate_redshift_dump_times()
+            if self.cosmological_simulation:
+                for output in self.all_redshift_outputs:
+                    output["time"] = self.cosmology.t_from_z(output["redshift"])
+                self.all_redshift_outputs.sort(key=lambda obj:obj["time"])
 
             self.all_outputs = self.all_time_outputs + self.all_redshift_outputs
             if self.parameters['CycleSkipDataDump'] <= 0:
@@ -496,9 +501,9 @@ class EnzoSimulation(SimulationTimeSeries):
 
         # Convert initial/final redshifts to times.
         if self.cosmological_simulation:
-            self.initial_time = self.enzo_cosmology.t_from_z(self.initial_redshift)
+            self.initial_time = self.cosmology.t_from_z(self.initial_redshift)
             self.initial_time.units.registry = self.unit_registry
-            self.final_time = self.enzo_cosmology.t_from_z(self.final_redshift)
+            self.final_time = self.cosmology.t_from_z(self.final_redshift)
             self.final_time.units.registry = self.unit_registry
 
         # If not a cosmology simulation, figure out the stopping criteria.
@@ -516,11 +521,15 @@ class EnzoSimulation(SimulationTimeSeries):
                     'StopCycle' in self.parameters):
                 raise NoStoppingCondition(self.parameter_filename)
             if self.final_time is None:
-                mylog.warn('Simulation %s has no stop time set, stopping condition will be based only on cycles.',
-                           self.parameter_filename)
+                mylog.warn(
+                    "Simulation %s has no stop time set, stopping condition " +
+                    "will be based only on cycles.",
+                    self.parameter_filename)
 
     def _set_parameter_defaults(self):
-        "Set some default parameters to avoid problems if they are not in the parameter file."
+        """
+        Set some default parameters to avoid problems if they are not in the parameter file.
+        """
 
         self.parameters['GlobalDir'] = self.directory
         self.parameters['DataDumpName'] = "data"
@@ -570,7 +579,9 @@ class EnzoSimulation(SimulationTimeSeries):
                 self.final_redshift = self.all_outputs[-1]['redshift']
 
     def _check_for_outputs(self, potential_outputs):
-        r"""Check a list of files to see if they are valid datasets."""
+        """
+        Check a list of files to see if they are valid datasets.
+        """
 
         only_on_root(mylog.info, "Checking %d potential outputs.", 
                      len(potential_outputs))
@@ -603,112 +614,10 @@ class EnzoSimulation(SimulationTimeSeries):
 
         return my_outputs
 
-    def _get_outputs_by_key(self, key, values, tolerance=None, outputs=None):
-        r"""Get datasets at or near to given values.
-
-        Parameters
-        ----------
-        key: str
-            The key by which to retrieve outputs, usually 'time' or
-            'redshift'.
-        values: array_like
-            A list of values, given as floats.
-        tolerance : float
-            If not None, do not return a dataset unless the value is
-            within the tolerance value.  If None, simply return the
-            nearest dataset.
-            Default: None.
-        outputs : list
-            The list of outputs from which to choose.  If None,
-            self.all_outputs is used.
-            Default: None.
-
-        Examples
-        --------
-        >>> datasets = es.get_outputs_by_key('redshift', [0, 1, 2], tolerance=0.1)
-
-        """
-
-        if not isinstance(values, np.ndarray):
-            values = ensure_list(values)
-        if outputs is None:
-            outputs = self.all_outputs
-        my_outputs = []
-        if not outputs:
-            return my_outputs
-        for value in values:
-            outputs.sort(key=lambda obj:np.abs(value - obj[key]))
-            if (tolerance is None or np.abs(value - outputs[0][key]) <= tolerance) \
-                    and outputs[0] not in my_outputs:
-                my_outputs.append(outputs[0])
-            else:
-                mylog.error("No dataset added for %s = %f.", key, value)
-
-        outputs.sort(key=lambda obj: obj['time'])
-        return my_outputs
-
-    def _get_outputs_by_redshift(self, redshifts, tolerance=None, outputs=None):
-        r"""Get datasets at or near to given redshifts.
-
-        Parameters
-        ----------
-        redshifts: array_like
-            A list of redshifts, given as floats.
-        tolerance : float
-            If not None, do not return a dataset unless the value is
-            within the tolerance value.  If None, simply return the
-            nearest dataset.
-            Default: None.
-        outputs : list
-            The list of outputs from which to choose.  If None,
-            self.all_outputs is used.
-            Default: None.
-
-        Examples
-        --------
-        >>> datasets = es.get_outputs_by_redshift([0, 1, 2], tolerance=0.1)
-
-        """
-
-        return self._get_outputs_by_key('redshift', redshifts, tolerance=tolerance,
-                                     outputs=outputs)
-
-    def _get_outputs_by_time(self, times, tolerance=None, outputs=None):
-        r"""Get datasets at or near to given times.
-
-        Parameters
-        ----------
-        times: tuple of type (float array, str)
-            A list of times for which outputs will be found and the units 
-            of those values.  For example, ([0, 1, 2, 3], "s").
-        tolerance : float
-            If not None, do not return a dataset unless the time is
-            within the tolerance value.  If None, simply return the
-            nearest dataset.
-            Default = None.
-        outputs : list
-            The list of outputs from which to choose.  If None,
-            self.all_outputs is used.
-            Default: None.
-
-        Examples
-        --------
-        >>> datasets = es.get_outputs_by_time([600, 500, 400], tolerance=10.)
-
-        """
-
-        if not isinstance(times, YTArray):
-            if isinstance(times, tuple) and len(times) == 2:
-                times = self.arr(*times)
-            else:
-                times = self.arr(times, "code_time")
-        times = times.in_units("s")
-        return self._get_outputs_by_key('time', times, tolerance=tolerance,
-                                        outputs=outputs)
-
     def _write_cosmology_outputs(self, filename, outputs, start_index,
                                  decimals=3):
-        r"""Write cosmology output parameters for a cosmology splice.
+        """
+        Write cosmology output parameters for a cosmology splice.
         """
 
         mylog.info("Writing redshift output list to %s.", filename)
