@@ -21,17 +21,18 @@ from itertools import groupby
 from yt.utilities.io_handler import \
     BaseIOHandler
 from yt.utilities.logger import ytLogger as mylog
+from yt.geometry.selection_routines import AlwaysSelector
 
 # http://stackoverflow.com/questions/2361945/detecting-consecutive-integers-in-a-list
 def particle_sequences(grids):
     g_iter = sorted(grids, key = lambda g: g.id)
-    for k, g in groupby(enumerate(g_iter), lambda (i,x):i-x.id):
+    for k, g in groupby(enumerate(g_iter), lambda i_x:i_x[0]-i_x[1].id):
         seq = list(v[1] for v in g)
         yield seq[0], seq[-1]
 
 def grid_sequences(grids):
     g_iter = sorted(grids, key = lambda g: g.id)
-    for k, g in groupby(enumerate(g_iter), lambda (i,x):i-x.id):
+    for k, g in groupby(enumerate(g_iter), lambda i_x1:i_x1[0]-i_x1[1].id):
         seq = list(v[1] for v in g)
         yield seq
 
@@ -46,7 +47,8 @@ class IOHandlerFLASH(BaseIOHandler):
         self._particle_handle = ds._particle_handle
         
         try :
-            particle_fields = [s[0].strip() for s in
+            particle_fields = [s[0].decode("ascii","ignore").strip()
+                               for s in
                                self._particle_handle["/particle names"][:]]
             self._particle_fields = dict([("particle_" + s, i) for i, s in
                                           enumerate(particle_fields)])
@@ -65,7 +67,7 @@ class IOHandlerFLASH(BaseIOHandler):
                       for ax in 'xyz')
         p_fields = f_part["/tracer particles"]
         assert(len(ptf) == 1)
-        ptype = ptf.keys()[0]
+        ptype = list(ptf.keys())[0]
         for chunk in chunks:
             start = end = None
             for g1, g2 in particle_sequences(chunk.objs):
@@ -84,7 +86,7 @@ class IOHandlerFLASH(BaseIOHandler):
                       for ax in 'xyz')
         p_fields = f_part["/tracer particles"]
         assert(len(ptf) == 1)
-        ptype = ptf.keys()[0]
+        ptype = list(ptf.keys())[0]
         field_list = ptf[ptype]
         for chunk in chunks:
             for g1, g2 in particle_sequences(chunk.objs):
@@ -132,7 +134,19 @@ class IOHandlerFLASH(BaseIOHandler):
         rv = {}
         for g in chunk.objs:
             rv[g.id] = {}
-        for field in fields:
+        # Split into particles and non-particles
+        fluid_fields, particle_fields = [], []
+        for ftype, fname in fields:
+            if ftype in self.ds.particle_types:
+                particle_fields.append((ftype, fname))
+            else:
+                fluid_fields.append((ftype, fname))
+        if len(particle_fields) > 0:
+            selector = AlwaysSelector(self.ds)
+            rv.update(self._read_particle_selection(
+                [chunk], selector, particle_fields))
+        if len(fluid_fields) == 0: return rv
+        for field in fluid_fields:
             ftype, fname = field
             ds = f["/%s" % fname]
             ind = 0
