@@ -201,7 +201,7 @@ class GDFDataset(Dataset):
                 else:
                     current_field_units = \
                         just_one(current_field.attrs['field_units'])
-                self.field_units[field_name] = current_field_units
+                self.field_units[field_name] = current_field_units.decode("utf8")
             else:
                 self.field_units[field_name] = ""
 
@@ -215,7 +215,7 @@ class GDFDataset(Dataset):
                     if unit_name in self.field_units:
                         mylog.warning("'field_units' was overridden by 'dataset_units/%s'"
                                       % (unit_name))
-                    self.field_units[unit_name] = unit
+                    self.field_units[unit_name] = unit.decode('utf8')
         else:
             self.length_unit = self.quan(1.0, "cm")
             self.mass_unit = self.quan(1.0, "g")
