@@ -17,52 +17,53 @@ from __future__ import print_function
 
 import glob
 import numpy as np
+from numpy.lib.recfunctions import append_fields
 import os
 
-from yt.geometry.oct_container import \
-    _ORDER_MAX
 from yt.utilities.io_handler import \
     BaseIOHandler
 from yt.utilities.lib.geometry_utils import \
     compute_morton
 from yt.utilities.logger import ytLogger as \
     mylog
-    
+
 CHUNKSIZE = 10000000
 
+
 class IOHandlerTipsyBinary(BaseIOHandler):
     _dataset_type = "tipsy"
     _vector_fields = ("Coordinates", "Velocity", "Velocities")
 
-    _pdtypes = None # dtypes, to be filled in later
+    _pdtypes = None  # dtypes, to be filled in later
+    _aux_pdtypes = None  # auxiliary files' dtypes
 
-    _ptypes = ( "Gas",
-                "DarkMatter",
-                "Stars" )
-    _chunksize = 64*64*64
+    _ptypes = ("Gas",
+               "DarkMatter",
+               "Stars")
+    _chunksize = 64 * 64 * 64
 
     _aux_fields = None
-    _fields = ( ("Gas", "Mass"),
-                ("Gas", "Coordinates"),
-                ("Gas", "Velocities"),
-                ("Gas", "Density"),
-                ("Gas", "Temperature"),
-                ("Gas", "Epsilon"),
-                ("Gas", "Metals"),
-                ("Gas", "Phi"),
-                ("DarkMatter", "Mass"),
-                ("DarkMatter", "Coordinates"),
-                ("DarkMatter", "Velocities"),
-                ("DarkMatter", "Epsilon"),
-                ("DarkMatter", "Phi"),
-                ("Stars", "Mass"),
-                ("Stars", "Coordinates"),
-                ("Stars", "Velocities"),
-                ("Stars", "Metals"),
-                ("Stars", "FormationTime"),
-                ("Stars", "Epsilon"),
-                ("Stars", "Phi")
-              )
+    _fields = (("Gas", "Mass"),
+               ("Gas", "Coordinates"),
+               ("Gas", "Velocities"),
+               ("Gas", "Density"),
+               ("Gas", "Temperature"),
+               ("Gas", "Epsilon"),
+               ("Gas", "Metals"),
+               ("Gas", "Phi"),
+               ("DarkMatter", "Mass"),
+               ("DarkMatter", "Coordinates"),
+               ("DarkMatter", "Velocities"),
+               ("DarkMatter", "Epsilon"),
+               ("DarkMatter", "Phi"),
+               ("Stars", "Mass"),
+               ("Stars", "Coordinates"),
+               ("Stars", "Velocities"),
+               ("Stars", "Metals"),
+               ("Stars", "FormationTime"),
+               ("Stars", "Epsilon"),
+               ("Stars", "Phi")
+               )
 
     def __init__(self, *args, **kwargs):
         self._aux_fields = []
@@ -71,50 +72,6 @@ class IOHandlerTipsyBinary(BaseIOHandler):
     def _read_fluid_selection(self, chunks, selector, fields, size):
         raise NotImplementedError
 
-    def _read_aux_fields(self, field, mask, data_file):
-        """
-        Read in auxiliary files from gasoline/pkdgrav.
-        This method will automatically detect the format of the file.
-        """
-        filename = data_file.filename+'.'+field
-        dtype = None
-        # We need to do some fairly ugly detection to see what format the auxiliary
-        # files are in.  They can be either ascii or binary, and the binary files can be
-        # either floats, ints, or doubles.  We're going to use a try-catch cascade to
-        # determine the format.
-        try:#ASCII
-            auxdata = np.genfromtxt(filename, skip_header=1)
-            if auxdata.size != np.sum(data_file.total_particles.values()):
-                print("Error reading auxiliary tipsy file")
-                raise RuntimeError 
-        except ValueError:#binary/xdr
-            f = open(filename, 'rb')
-            l = struct.unpack(data_file.ds.endian+"i", f.read(4))[0]
-            if l != np.sum(data_file.total_particles.values()):
-                print("Error reading auxiliary tipsy file")
-                raise RuntimeError
-            dtype = 'd'
-            if field in ('iord', 'igasorder', 'grp'):#These fields are integers
-                dtype = 'i'
-            try:# If we try loading doubles by default, we can catch an exception and try floats next
-                auxdata = np.array(struct.unpack(data_file.ds.endian+(l*dtype), f.read()))
-            except struct.error:
-                f.seek(4)
-                dtype = 'f'
-                try:
-                    auxdata = np.array(struct.unpack(data_file.ds.endian+(l*dtype), f.read()))
-                except struct.error: # None of the binary attempts to read succeeded
-                    print("Error reading auxiliary tipsy file")
-                    raise RuntimeError
-
-        # Use the mask to slice out the appropriate particle type data
-        if mask.size == data_file.total_particles['Gas']:
-            return auxdata[:data_file.total_particles['Gas']]
-        elif mask.size == data_file.total_particles['DarkMatter']:
-            return auxdata[data_file.total_particles['Gas']:-data_file.total_particles['DarkMatter']]
-        else:
-            return auxdata[-data_file.total_particles['Stars']:]
-
     def _fill_fields(self, fields, vals, mask, data_file):
         if mask is None:
             size = 0
@@ -123,27 +80,26 @@ class IOHandlerTipsyBinary(BaseIOHandler):
         rv = {}
         for field in fields:
             mylog.debug("Allocating %s values for %s", size, field)
-            if field in self._aux_fields: #Read each of the auxiliary fields
-                rv[field] = self._read_aux_fields(field, mask, data_file)
-            elif field in self._vector_fields:
+            if field in self._vector_fields:
                 rv[field] = np.empty((size, 3), dtype="float64")
-                if size == 0: continue
-                rv[field][:,0] = vals[field]['x'][mask]
-                rv[field][:,1] = vals[field]['y'][mask]
-                rv[field][:,2] = vals[field]['z'][mask]
+                if size == 0:
+                    continue
+                rv[field][:, 0] = vals[field]['x'][mask]
+                rv[field][:, 1] = vals[field]['y'][mask]
+                rv[field][:, 2] = vals[field]['z'][mask]
             else:
                 rv[field] = np.empty(size, dtype="float64")
-                if size == 0: continue
+                if size == 0:
+                    continue
                 rv[field][:] = vals[field][mask]
             if field == "Coordinates":
                 eps = np.finfo(rv[field].dtype).eps
                 for i in range(3):
-                  rv[field][:,i] = np.clip(rv[field][:,i],
-                      self.domain_left_edge[i] + eps,
-                      self.domain_right_edge[i] - eps)
+                    rv[field][:, i] = np.clip(rv[field][:, i],
+                                              self.domain_left_edge[i] + eps,
+                                              self.domain_right_edge[i] - eps)
         return rv
 
-
     def _read_particle_coords(self, chunks, ptf):
         data_files = set([])
         for chunk in chunks:
@@ -153,14 +109,16 @@ class IOHandlerTipsyBinary(BaseIOHandler):
             poff = data_file.field_offsets
             tp = data_file.total_particles
             f = open(data_file.filename, "rb")
-            for ptype, field_list in sorted(ptf.items(), key=lambda a: poff[a[0]]):
+            for ptype, field_list in sorted(ptf.items(),
+                                            key=lambda a: poff[a[0]]):
                 f.seek(poff[ptype], os.SEEK_SET)
                 total = 0
                 while total < tp[ptype]:
-                    p = np.fromfile(f, self._pdtypes[ptype],
-                            count=min(self._chunksize, tp[ptype] - total))
+                    count = min(self._chunksize, tp[ptype] - total)
+                    p = np.fromfile(f, self._pdtypes[ptype], count=count)
                     total += p.size
-                    d = [p["Coordinates"][ax].astype("float64") for ax in 'xyz']
+                    d = [p["Coordinates"][ax].astype("float64")
+                         for ax in 'xyz']
                     del p
                     yield ptype, d
 
@@ -172,24 +130,68 @@ class IOHandlerTipsyBinary(BaseIOHandler):
                 data_files.update(obj.data_files)
         for data_file in sorted(data_files):
             poff = data_file.field_offsets
+            aux_fields_offsets = \
+                self._calculate_particle_offsets_aux(data_file)
             tp = data_file.total_particles
             f = open(data_file.filename, "rb")
-            for ptype, field_list in sorted(ptf.items(), key=lambda a: poff[a[0]]):
+
+            # we need to open all aux files for chunking to work
+            aux_fh = {}
+            for afield in self._aux_fields:
+                aux_fh[afield] = open(data_file.filename + '.' + afield, 'rb')
+
+            for ptype, field_list in sorted(ptf.items(),
+                                            key=lambda a: poff[a[0]]):
                 f.seek(poff[ptype], os.SEEK_SET)
+                afields = list(set(field_list).intersection(self._aux_fields))
+                for afield in afields:
+                    aux_fh[afield].seek(
+                        aux_fields_offsets[afield][ptype][0], os.SEEK_SET)
+
                 total = 0
                 while total < tp[ptype]:
-                    p = np.fromfile(f, self._pdtypes[ptype],
-                        count=min(self._chunksize, tp[ptype] - total))
+                    count = min(self._chunksize, tp[ptype] - total)
+                    p = np.fromfile(f, self._pdtypes[ptype], count=count)
+
+                    auxdata = []
+                    for afield in afields:
+                        if isinstance(self._aux_pdtypes[afield], np.dtype):
+                            auxdata.append(
+                                np.fromfile(aux_fh[afield],
+                                            self._aux_pdtypes[afield],
+                                            count=count)
+                            )
+                        else:
+                            aux_fh[afield].seek(0, os.SEEK_SET)
+                            sh = aux_fields_offsets[afield][ptype][0] + total
+                            sf = aux_fields_offsets[afield][ptype][1] + \
+                                tp[ptype] - count
+                            if tp[ptype] > 0:
+                                aux = np.genfromtxt(
+                                    aux_fh[afield], skip_header=sh,
+                                    skip_footer=sf
+                                )
+                                if aux.ndim < 1:
+                                    aux = np.array([aux])
+                                auxdata.append(aux)
+
                     total += p.size
+                    if afields:
+                        p = append_fields(p, afields, auxdata)
                     mask = selector.select_points(
                         p["Coordinates"]['x'].astype("float64"),
                         p["Coordinates"]['y'].astype("float64"),
                         p["Coordinates"]['z'].astype("float64"), 0.0)
-                    if mask is None: continue
+                    if mask is None:
+                        continue
                     tf = self._fill_fields(field_list, p, mask, data_file)
                     for field in field_list:
                         yield (ptype, field), tf.pop(field)
+
+            # close all file handles
             f.close()
+            for fh in list(aux_fh.values()):
+                fh.close()
 
     def _update_domain(self, data_file):
         '''
@@ -201,24 +203,25 @@ class IOHandlerTipsyBinary(BaseIOHandler):
         ind = 0
         # Check to make sure that the domain hasn't already been set
         # by the parameter file
-        if np.all(np.isfinite(ds.domain_left_edge)) and np.all(np.isfinite(ds.domain_right_edge)):
+        if np.all(np.isfinite(ds.domain_left_edge)) and \
+                np.all(np.isfinite(ds.domain_right_edge)):
             return
         with open(data_file.filename, "rb") as f:
             ds.domain_left_edge = 0
             ds.domain_right_edge = 0
             f.seek(ds._header_offset)
-            mi =   np.array([1e30, 1e30, 1e30], dtype="float64")
-            ma =  -np.array([1e30, 1e30, 1e30], dtype="float64")
+            mi = np.array([1e30, 1e30, 1e30], dtype="float64")
+            ma = -np.array([1e30, 1e30, 1e30], dtype="float64")
             for iptype, ptype in enumerate(self._ptypes):
                 # We'll just add the individual types separately
                 count = data_file.total_particles[ptype]
-                if count == 0: continue
-                start, stop = ind, ind + count
+                if count == 0:
+                    continue
+                stop = ind + count
                 while ind < stop:
                     c = min(CHUNKSIZE, stop - ind)
-                    pp = np.fromfile(f, dtype = self._pdtypes[ptype],
-                                     count = c)
-                    eps = np.finfo(pp["Coordinates"]["x"].dtype).eps
+                    pp = np.fromfile(f, dtype=self._pdtypes[ptype],
+                                     count=c)
                     np.minimum(mi, [pp["Coordinates"]["x"].min(),
                                     pp["Coordinates"]["y"].min(),
                                     pp["Coordinates"]["z"].min()], mi)
@@ -234,15 +237,14 @@ class IOHandlerTipsyBinary(BaseIOHandler):
         ds.domain_right_edge = ds.arr(ma, 'code_length')
         ds.domain_width = DW = ds.domain_right_edge - ds.domain_left_edge
         ds.unit_registry.add("unitary", float(DW.max() * DW.units.base_value),
-                                 DW.units.dimensions)
+                             DW.units.dimensions)
 
     def _initialize_index(self, data_file, regions):
         ds = data_file.ds
-        morton = np.empty(sum(data_file.total_particles.values()),
+        morton = np.empty(sum(list(data_file.total_particles.values())),
                           dtype="uint64")
         ind = 0
         DLE, DRE = ds.domain_left_edge, ds.domain_right_edge
-        dx = (DRE - DLE) / (2**_ORDER_MAX)
         self.domain_left_edge = DLE.in_units("code_length").ndarray_view()
         self.domain_right_edge = DRE.in_units("code_length").ndarray_view()
         with open(data_file.filename, "rb") as f:
@@ -250,28 +252,29 @@ class IOHandlerTipsyBinary(BaseIOHandler):
             for iptype, ptype in enumerate(self._ptypes):
                 # We'll just add the individual types separately
                 count = data_file.total_particles[ptype]
-                if count == 0: continue
-                start, stop = ind, ind + count
+                if count == 0:
+                    continue
+                stop = ind + count
                 while ind < stop:
                     c = min(CHUNKSIZE, stop - ind)
-                    pp = np.fromfile(f, dtype = self._pdtypes[ptype],
-                                     count = c)
+                    pp = np.fromfile(f, dtype=self._pdtypes[ptype],
+                                     count=c)
                     mis = np.empty(3, dtype="float64")
                     mas = np.empty(3, dtype="float64")
                     for axi, ax in enumerate('xyz'):
                         mi = pp["Coordinates"][ax].min()
                         ma = pp["Coordinates"][ax].max()
-                        mylog.debug("Spanning: %0.3e .. %0.3e in %s", mi, ma, ax)
+                        mylog.debug(
+                            "Spanning: %0.3e .. %0.3e in %s", mi, ma, ax)
                         mis[axi] = mi
                         mas[axi] = ma
                     pos = np.empty((pp.size, 3), dtype="float64")
                     for i, ax in enumerate("xyz"):
-                        eps = np.finfo(pp["Coordinates"][ax].dtype).eps
-                        pos[:,i] = pp["Coordinates"][ax]
+                        pos[:, i] = pp["Coordinates"][ax]
                     regions.add_data_file(pos, data_file.file_id,
                                           data_file.ds.filter_bbox)
-                    morton[ind:ind+c] = compute_morton(
-                        pos[:,0], pos[:,1], pos[:,2],
+                    morton[ind:ind + c] = compute_morton(
+                        pos[:, 0], pos[:, 1], pos[:, 2],
                         DLE, DRE, data_file.ds.filter_bbox)
                     ind += c
         mylog.info("Adding %0.3e particles", morton.size)
@@ -286,7 +289,7 @@ class IOHandlerTipsyBinary(BaseIOHandler):
         return npart
 
     @classmethod
-    def _compute_dtypes(cls, field_dtypes, endian = "<"):
+    def _compute_dtypes(cls, field_dtypes, endian="<"):
         pds = {}
         for ptype, field in cls._fields:
             dtbase = field_dtypes.get(field, 'f')
@@ -304,27 +307,51 @@ class IOHandlerTipsyBinary(BaseIOHandler):
     def _create_dtypes(self, data_file):
         # We can just look at the particle counts.
         self._header_offset = data_file.ds._header_offset
-        self._pdtypes = {}
-        pds = {}
-        field_list = []
-        tp = data_file.total_particles
-        aux_filenames = glob.glob(data_file.filename+'.*') # Find out which auxiliaries we have
-        self._aux_fields = [f[1+len(data_file.filename):] for f in aux_filenames]
         self._pdtypes = self._compute_dtypes(data_file.ds._field_dtypes,
                                              data_file.ds.endian)
+        self._field_list = []
         for ptype, field in self._fields:
-            if tp[ptype] == 0:
+            if data_file.total_particles[ptype] == 0:
                 # We do not want out _pdtypes to have empty particles.
                 self._pdtypes.pop(ptype, None)
                 continue
-            field_list.append((ptype, field))
-        if any(["Gas"==f[0] for f in field_list]): #Add the auxiliary fields to each ptype we have
-            field_list += [("Gas",a) for a in self._aux_fields]
-        if any(["DarkMatter"==f[0] for f in field_list]):
-            field_list += [("DarkMatter",a) for a in self._aux_fields]
-        if any(["Stars"==f[0] for f in field_list]):
-            field_list += [("Stars",a) for a in self._aux_fields]
-        self._field_list = field_list
+            self._field_list.append((ptype, field))
+
+        # Find out which auxiliaries we have and what is their format
+        tot_parts = np.sum(list(data_file.total_particles.values()))
+        endian = data_file.ds.endian
+        self._aux_pdtypes = {}
+        self._aux_fields = [f.rsplit('.')[-1]
+                            for f in glob.glob(data_file.filename + '.*')]
+        for afield in self._aux_fields:
+            filename = data_file.filename + '.' + afield
+            # We need to do some fairly ugly detection to see what format the
+            # auxiliary files are in.  They can be either ascii or binary, and
+            # the binary files can be either floats, ints, or doubles.  We're
+            # going to use a try-catch cascade to determine the format.
+            filesize = os.stat(filename).st_size
+            if np.fromfile(filename, np.dtype(endian + 'i4'),
+                           count=1) != tot_parts:
+                with open(filename, 'rb') as f:
+                    header_nparts = f.readline()
+                    if int(header_nparts) != tot_parts:
+                        raise RuntimeError
+                self._aux_pdtypes[afield] = "ascii"
+            elif (filesize - 4) / 8 == tot_parts:
+                self._aux_pdtypes[afield] = np.dtype([('aux', endian + 'd')])
+            elif (filesize - 4) / 4 == tot_parts:
+                if afield.startswith("i"):
+                    self._aux_pdtypes[afield] = np.dtype([('aux', endian + 'i')])
+                else:
+                    self._aux_pdtypes[afield] = np.dtype([('aux', endian + 'f')])
+            else:
+                raise RuntimeError
+
+        # Add the auxiliary fields to each ptype we have
+        for ptype in self._ptypes:
+            if any([ptype == field[0] for field in self._field_list]):
+                self._field_list += \
+                    [(ptype, afield) for afield in self._aux_fields]
         return self._field_list
 
     def _identify_fields(self, data_file):
@@ -335,7 +362,29 @@ class IOHandlerTipsyBinary(BaseIOHandler):
         pos = data_file.ds._header_offset
         for ptype in self._ptypes:
             field_offsets[ptype] = pos
-            if data_file.total_particles[ptype] == 0: continue
+            if data_file.total_particles[ptype] == 0:
+                continue
             size = self._pdtypes[ptype].itemsize
             pos += data_file.total_particles[ptype] * size
         return field_offsets
+
+    def _calculate_particle_offsets_aux(self, data_file):
+        aux_fields_offsets = {}
+        tp = data_file.total_particles
+        for afield in self._aux_fields:
+            aux_fields_offsets[afield] = {}
+            if isinstance(self._aux_pdtypes[afield], np.dtype):
+                pos = 4  # i4
+                for ptype in self._ptypes:
+                    aux_fields_offsets[afield][ptype] = (pos, 0)
+                    if data_file.total_particles[ptype] == 0:
+                        continue
+                    size = np.dtype(self._aux_pdtypes[afield]).itemsize
+                    pos += data_file.total_particles[ptype] * size
+            else:
+                aux_fields_offsets[afield].update(
+                    {'Gas': (1, tp["DarkMatter"] + tp["Stars"]),
+                     'DarkMatter': (1 + tp["Gas"], tp["Stars"]),
+                     'Stars': (1 + tp["DarkMatter"] + tp["Gas"], 0)}
+                )
+        return aux_fields_offsets
