@@ -134,7 +134,7 @@ class CylindricalCoordinateHandler(CoordinateHandler):
     _image_axis_name = None
 
     @property
-    def image_axis_name(self):    
+    def image_axis_name(self):
         if self._image_axis_name is not None:
             return self._image_axis_name
         # This is the x and y axes labels that get displayed.  For
@@ -192,3 +192,23 @@ class CylindricalCoordinateHandler(CoordinateHandler):
             display_center[z_ax] = self.ds.domain_center[z_ax]
             # zeros for the others
         return center, display_center
+
+    def sanitize_width(self, axis, width, depth):
+        name = self.axis_name[axis]
+        r_ax, theta_ax, z_ax = (self.ds.coordinates.axis_id[ax]
+                                for ax in ('r', 'theta', 'z'))
+        if width is not None:
+             width = super(CylindricalCoordinateHandler,
+                           self).sanitize_width(axis, width, depth)
+        # Note: regardless of axes, these are set up to give consistent plots
+        # when plotted, which is not strictly a "right hand rule" for axes.
+        elif name == "r": # soup can label
+            width = [2.0 * np.pi * self.ds.domain_width.uq,
+                     self.ds.domain_width[z_ax]]
+        elif name == "theta":
+            width = [self.ds.domain_right_edge[r_ax],
+                     self.ds.domain_width[z_ax]]
+        elif name == "z":
+            width = [2.0*self.ds.domain_right_edge[r_ax],
+                     2.0*self.ds.domain_right_edge[r_ax]]
+        return width
