@@ -158,8 +158,13 @@ class Unit(Expr):
                     # Bug catch...
                     # if unit_expr is an empty string, parse_expr fails hard...
                     unit_expr = "1"
-                unit_expr = parse_expr(unit_expr, global_dict=global_dict,
-                                       transformations=unit_text_transform)
+                try:
+                    unit_expr = parse_expr(unit_expr, global_dict=global_dict,
+                                           transformations=unit_text_transform)
+                except SyntaxError as e:
+                    msg = ("Unit expression %s raised an error "
+                           "during parsing:\n%s" % (unit_expr, repr(e)))
+                    raise UnitParseError(msg)
         elif isinstance(unit_expr, Unit):
             # grab the unit object's sympy expression.
             unit_expr = unit_expr.expr
@@ -373,9 +378,15 @@ class Unit(Expr):
         # Use sympy to factor the dimensions into base CGS unit symbols.
         units = []
         my_dims = self.dimensions.expand()
-        for dim in base_units:
+        if my_dims is dimensionless:
+            return ""
+        for factor in my_dims.as_ordered_factors():
+            dim = list(factor.free_symbols)[0]
             unit_string = base_units[dim]
-            power_string = "**(%s)" % my_dims.as_coeff_exponent(dim)[1]
+            if factor.is_Pow:
+                power_string = "**(%s)" % factor.as_base_exp()[1]
+            else:
+                power_string = ""
             units.append("".join([unit_string, power_string]))
         return " * ".join(units)
 
