@@ -4,6 +4,7 @@ Answer Testing using Nose as a starting point
 
 
 """
+from __future__ import print_function
 
 #-----------------------------------------------------------------------------
 # Copyright (c) 2013, yt Development Team.
@@ -17,10 +18,8 @@ import logging
 import os
 import hashlib
 import contextlib
-import urllib2
-import cPickle
 import sys
-import cPickle
+from yt.extern.six.moves import cPickle, urllib
 import shelve
 import zlib
 import tempfile
@@ -121,7 +120,7 @@ class AnswerTesting(Plugin):
         # Local/Cloud storage
         if options.local_results:
             if options.output_dir is None:
-                print 'Please supply an output directory with the --local-dir option'
+                print('Please supply an output directory with the --local-dir option')
                 sys.exit(1)
             storage_class = AnswerTestLocalStorage
             # Fix up filename for local storage
@@ -129,7 +128,7 @@ class AnswerTesting(Plugin):
                 self.compare_name = "%s/%s/%s" % \
                     (os.path.realpath(options.output_dir), self.compare_name,
                      self.compare_name)
-            if self.store_name is not None:
+            if self.store_name is not None and options.store_results:
                 name_dir_path = "%s/%s" % \
                     (os.path.realpath(options.output_dir),
                     self.store_name)
@@ -169,10 +168,10 @@ class AnswerTestCloudStorage(AnswerTestStorage):
     def get(self, ds_name, default = None):
         if self.reference_name is None: return default
         if ds_name in self.cache: return self.cache[ds_name]
-        url = _url_path % (self.reference_name, ds_name)
+        url = _url_path.format(self.reference_name, ds_name)
         try:
-            resp = urllib2.urlopen(url)
-        except urllib2.HTTPError as ex:
+            resp = urllib.request.urlopen(url)
+        except urllib.error.HTTPError as ex:
             raise YTNoOldAnswer(url)
         else:
             for this_try in range(3):
@@ -277,16 +276,16 @@ def can_run_sim(sim_fn, sim_type, file_check = False):
     return AnswerTestingTest.result_storage is not None
 
 def data_dir_load(ds_fn, cls = None, args = None, kwargs = None):
+    args = args or ()
+    kwargs = kwargs or {}
     path = ytcfg.get("yt", "test_data_dir")
     if isinstance(ds_fn, Dataset): return ds_fn
     if not os.path.isdir(path):
         return False
     with temp_cwd(path):
         if cls is None:
-            ds = load(ds_fn)
+            ds = load(ds_fn, *args, **kwargs)
         else:
-            args = args or ()
-            kwargs = kwargs or {}
             ds = cls(ds_fn, *args, **kwargs)
         ds.index
         return ds
@@ -404,8 +403,8 @@ class FieldValuesTest(AnswerTestingTest):
             assert_equal(new_result, old_result,
                          err_msg=err_msg, verbose=True)
         else:
-            assert_allclose(new_result, old_result, 10.**(-self.decimals),
-                             err_msg=err_msg, verbose=True)
+            assert_allclose_units(new_result, old_result, 10.**(-self.decimals),
+                                  err_msg=err_msg, verbose=True)
 
 class AllFieldValuesTest(AnswerTestingTest):
     _type_name = "AllFieldValues"
@@ -479,8 +478,8 @@ class ProjectionValuesTest(AnswerTestingTest):
             if self.decimals is None:
                 assert_equal(nres, ores, err_msg=err_msg)
             else:
-                assert_allclose(nres, ores, 10.**-(self.decimals),
-                                err_msg=err_msg)
+                assert_allclose_units(nres, ores, 10.**-(self.decimals),
+                                      err_msg=err_msg)
 
 class PixelizedProjectionValuesTest(AnswerTestingTest):
     _type_name = "PixelizedProjectionValues"
@@ -609,13 +608,13 @@ class SimulatedHaloMassFunctionTest(AnswerTestingTest):
     def __init__(self, ds_fn, finder):
         super(SimulatedHaloMassFunctionTest, self).__init__(ds_fn)
         self.finder = finder
-    
+
     def run(self):
         from yt.analysis_modules.halo_analysis.api import HaloCatalog
         from yt.analysis_modules.halo_mass_function.api import HaloMassFcn
         hc = HaloCatalog(data_ds=self.ds, finder_method=self.finder)
         hc.create()
-        
+
         hmf = HaloMassFcn(halos_ds=hc.halos_ds)
         result = np.empty((2, hmf.masses_sim.size))
         result[0] = hmf.masses_sim.d
@@ -635,7 +634,7 @@ class AnalyticHaloMassFunctionTest(AnswerTestingTest):
     def __init__(self, ds_fn, fitting_function):
         super(AnalyticHaloMassFunctionTest, self).__init__(ds_fn)
         self.fitting_function = fitting_function
-    
+
     def run(self):
         from yt.analysis_modules.halo_mass_function.api import HaloMassFcn
         hmf = HaloMassFcn(simulation_ds=self.ds,
@@ -655,17 +654,19 @@ def compare_image_lists(new_result, old_result, decimals):
     fns = ['old.png', 'new.png']
     num_images = len(old_result)
     assert(num_images > 0)
-    for i in xrange(num_images):
+    for i in range(num_images):
         mpimg.imsave(fns[0], np.loads(zlib.decompress(old_result[i])))
         mpimg.imsave(fns[1], np.loads(zlib.decompress(new_result[i])))
-        assert compare_images(fns[0], fns[1], 10**(decimals)) == None
+        assert compare_images(fns[0], fns[1], 10**(-decimals)) == None
         for fn in fns: os.remove(fn)
-            
+
 class PlotWindowAttributeTest(AnswerTestingTest):
     _type_name = "PlotWindowAttribute"
-    _attrs = ('plot_type', 'plot_field', 'plot_axis', 'attr_name', 'attr_args')
+    _attrs = ('plot_type', 'plot_field', 'plot_axis', 'attr_name', 'attr_args',
+              'callback_id')
     def __init__(self, ds_fn, plot_field, plot_axis, attr_name, attr_args,
-                 decimals, plot_type = 'SlicePlot'):
+                 decimals, plot_type = 'SlicePlot', callback_id = "",
+                 callback_runners = None):
         super(PlotWindowAttributeTest, self).__init__(ds_fn)
         self.plot_type = plot_type
         self.plot_field = plot_field
@@ -674,10 +675,18 @@ class PlotWindowAttributeTest(AnswerTestingTest):
         self.attr_name = attr_name
         self.attr_args = attr_args
         self.decimals = decimals
+        # callback_id is so that we don't have to hash the actual callbacks
+        # run, but instead we call them something
+        self.callback_id = callback_id
+        if callback_runners is None:
+            callback_runners = []
+        self.callback_runners = callback_runners
 
     def run(self):
         plot = self.create_plot(self.ds, self.plot_type, self.plot_field,
                                 self.plot_axis, self.plot_kwargs)
+        for r in self.callback_runners:
+            r(self, plot)
         attr = getattr(plot, self.attr_name)
         attr(*self.attr_args[0], **self.attr_args[1])
         tmpfd, tmpname = tempfile.mkstemp(suffix='.png')
@@ -696,7 +705,7 @@ class GenericArrayTest(AnswerTestingTest):
     def __init__(self, ds_fn, array_func, args=None, kwargs=None, decimals=None):
         super(GenericArrayTest, self).__init__(ds_fn)
         self.array_func = array_func
-        self.array_func_name = array_func.func_name
+        self.array_func_name = array_func.__name__
         self.args = args
         self.kwargs = kwargs
         self.decimals = decimals
@@ -718,7 +727,8 @@ class GenericArrayTest(AnswerTestingTest):
             if self.decimals is None:
                 assert_equal(new_result[k], old_result[k])
             else:
-                assert_allclose(new_result[k], old_result[k], 10**(-self.decimals))
+                assert_allclose_units(new_result[k], old_result[k],
+                                      10**(-self.decimals))
 
 class GenericImageTest(AnswerTestingTest):
     _type_name = "GenericImage"
@@ -726,7 +736,7 @@ class GenericImageTest(AnswerTestingTest):
     def __init__(self, ds_fn, image_func, decimals, args=None, kwargs=None):
         super(GenericImageTest, self).__init__(ds_fn)
         self.image_func = image_func
-        self.image_func_name = image_func.func_name
+        self.image_func_name = image_func.__name__
         self.args = args
         self.kwargs = kwargs
         self.decimals = decimals
@@ -764,7 +774,7 @@ def requires_sim(sim_fn, sim_type, big_data = False, file_check = False):
         return ffalse
     else:
         return ftrue
-        
+
 def requires_ds(ds_fn, big_data = False, file_check = False):
     def ffalse(func):
         return lambda: None
