@@ -1,7 +1,8 @@
+from __future__ import absolute_import
 import matplotlib
 from yt.mods import *
 import pylab
-from output_tests import SingleOutputTest, YTDatasetTest, create_test
+from .output_tests import SingleOutputTest, YTDatasetTest, create_test
 
 class TestParticleUniqueIDs(YTDatasetTest):
 
@@ -36,7 +37,7 @@ class TestParticleExtrema(YTDatasetTest):
         max = min.copy()
         dims = ["particle_position_x","particle_position_y",
             "particle_position_z"]
-        for i in xrange(3):
+        for i in range(3):
             min[i] = np.min(all[dims[i]])
             max[i] = np.max(all[dims[i]])
         self.result = (min,max)
