@@ -21,7 +21,7 @@ from yt.startup_tasks import parser, subparsers
 from yt.mods import *
 from yt.funcs import *
 from yt.extern.six import add_metaclass
-from yt.extern.six.moves import urllib
+from yt.extern.six.moves import urllib, input
 from yt.utilities.minimal_representation import MinimalProjectDescription
 import argparse, os, os.path, math, sys, time, subprocess, getpass, tempfile
 import base64, os
@@ -302,7 +302,7 @@ def _get_yt_stack_date():
     if not os.path.exists(date_file):
         print("Could not determine when yt stack was last updated.")
         return
-    print("".join(file(date_file, 'r').readlines()))
+    print("".join(open(date_file, 'r').readlines()))
     print("To update all dependencies, run \"yt update --all\".")
 
 def _update_yt_stack(path):
@@ -322,7 +322,7 @@ def _update_yt_stack(path):
     print()
     print("[hit enter to continue or Ctrl-C to stop]")
     try:
-        raw_input()
+        input()
     except:
         sys.exit(0)
     os.environ["REINST_YT"] = "1"
@@ -358,7 +358,7 @@ def bb_apicall(endpoint, data, use_pass = True):
         data = urllib.parse.urlencode(data)
     req = urllib.request.Request(uri, data)
     if use_pass:
-        username = raw_input("Bitbucket Username? ")
+        username = input("Bitbucket Username? ")
         password = getpass.getpass()
         upw = '%s:%s' % (username, password)
         req.add_header('Authorization', 'Basic %s' % base64.b64encode(upw).strip())
@@ -396,7 +396,7 @@ class YTBugreportCmd(YTCommand):
         print("   http://yt-project.org/irc.html")
         print("   http://lists.spacepope.org/listinfo.cgi/yt-users-spacepope.org")
         print()
-        summary = raw_input("Press <enter> if you remain firm in your conviction to continue.")
+        summary = input("Press <enter> if you remain firm in your conviction to continue.")
         print()
         print()
         print("Okay, sorry about that. How about a nice, pithy ( < 12 words )")
@@ -407,7 +407,7 @@ class YTBugreportCmd(YTCommand):
             current_version = get_yt_version()
         except:
             current_version = "Unavailable"
-        summary = raw_input("Summary? ")
+        summary = input("Summary? ")
         bugtype = "bug"
         data = dict(title = summary, type=bugtype)
         print()
@@ -419,7 +419,7 @@ class YTBugreportCmd(YTCommand):
         if "EDITOR" in os.environ:
             print()
             print("Press enter to spawn your editor, %s" % os.environ["EDITOR"])
-            loki = raw_input()
+            input()
             tf = tempfile.NamedTemporaryFile(delete=False)
             fn = tf.name
             tf.close()
@@ -440,7 +440,7 @@ class YTBugreportCmd(YTCommand):
             print()
             lines = []
             while 1:
-                line = raw_input()
+                line = input()
                 if line.strip() == "---": break
                 lines.append(line)
             content = "\n".join(lines)
@@ -464,7 +464,7 @@ class YTBugreportCmd(YTCommand):
         print("'submit'.  Next we'll ask for your Bitbucket Username.")
         print("If you don't have one, run the 'yt bootstrap_dev' command.")
         print()
-        loki = raw_input()
+        input()
         retval = bb_apicall(endpoint, data, use_pass=True)
         import json
         retval = json.loads(retval)
@@ -505,17 +505,17 @@ class YTHubRegisterCmd(YTCommand):
         print()
         print("What username would you like to go by?")
         print()
-        username = raw_input("Username? ")
+        username = input("Username? ")
         if len(username) == 0: sys.exit(1)
         print()
         print("To start out, what's your name?")
         print()
-        name = raw_input("Name? ")
+        name = input("Name? ")
         if len(name) == 0: sys.exit(1)
         print()
         print("And your email address?")
         print()
-        email = raw_input("Email? ")
+        email = input("Email? ")
         if len(email) == 0: sys.exit(1)
         print()
         print("Please choose a password:")
@@ -531,12 +531,12 @@ class YTHubRegisterCmd(YTCommand):
         print("Would you like a URL displayed for your user?")
         print("Leave blank if no.")
         print()
-        url = raw_input("URL? ")
+        url = input("URL? ")
         print()
         print("Okay, press enter to register.  You should receive a welcome")
         print("message at %s when this is complete." % email)
         print()
-        loki = raw_input()
+        input()
         data = dict(name = name, email = email, username = username,
                     password = password1, password2 = password2,
                     url = url, zap = "rowsdower")
