@@ -21,12 +21,13 @@ Delaunay triangulation:
    tsearch
 
 """
+from __future__ import absolute_import
 
-from kdtree import *
+from .kdtree import *
 from .ckdtree import *
 #from qhull import *
 
-__all__ = filter(lambda s: not s.startswith('_'), dir())
+__all__ = list(filter(lambda s: not s.startswith('_'), dir()))
 __all__ += ['distance']
 
 from . import distance
