@@ -713,6 +713,8 @@ class PhasePlot(ImagePlotContainer):
     plot_title = None
     _plot_valid = False
     _plot_type = 'Phase'
+    _xlim = (None, None)
+    _ylim = (None, None)
 
     def __init__(self, data_source, x_field, y_field, z_fields,
                  weight_field="cell_mass", x_bins=128, y_bins=128,
@@ -807,6 +809,10 @@ class PhasePlot(ImagePlotContainer):
         scales = {True: 'log', False: 'linear'}
         return scales[x_log], scales[y_log], scales[z_log]
 
+    def _recreate_frb(self):
+        # needed for API compatibility with PlotWindow
+        pass
+
     def _setup_plots(self):
         if self._plot_valid:
             return
@@ -817,6 +823,8 @@ class PhasePlot(ImagePlotContainer):
             draw_colorbar = True
             draw_axes = True
             zlim = (None, None)
+            xlim = self._xlim
+            ylim = self._ylim
             if f in self.plots:
                 draw_colorbar = self.plots[f]._draw_colorbar
                 draw_axes = self.plots[f]._draw_axes
@@ -872,6 +880,9 @@ class PhasePlot(ImagePlotContainer):
             self.plots[f].axes.yaxis.set_label_text(y_title)
             self.plots[f].cax.yaxis.set_label_text(z_title)
 
+            self.plots[f].axes.set_xlim(xlim)
+            self.plots[f].axes.set_ylim(ylim)
+
             if f in self._plot_text:
                 self.plots[f].axes.text(self._text_xpos[f], self._text_ypos[f],
                                         self._plot_text[f],
@@ -1177,6 +1188,7 @@ class PhasePlot(ImagePlotContainer):
             **additional_kwargs)
         for field in zunits:
             self.profile.set_field_unit(field, zunits[field])
+        self._xlim = (xmin, xmax)
         return self
 
     @invalidate_plot
@@ -1241,6 +1253,7 @@ class PhasePlot(ImagePlotContainer):
             **additional_kwargs)
         for field in zunits:
             self.profile.set_field_unit(field, zunits[field])
+        self._ylim = (ymin, ymax)
         return self
 
 
